@@ -53,7 +53,7 @@ def get_type(t: SpectreType, name = None):
     Convert from a generic Spectre type to a specific Java type. Name of field is used if type is an enum, not needed otherwise
     '''
     if t is SpectreType.INT:
-        return 'int'
+        return 'Integer'
     if t is SpectreType.STRING:
         return 'String'
     if t is SpectreType.TIMESTAMP:
@@ -61,7 +61,7 @@ def get_type(t: SpectreType, name = None):
     if t is SpectreType.BOOL:
         return 'boolean'
     if t is SpectreType.FLOAT:
-        return 'double'
+        return 'Double'
     if t is SpectreType.ENUM:
         return 'String'
     if t is SpectreType.UUID:
